%global		srcname embree

Name:		%{srcname}2
Version:	2.17.7
Release:	2%{?dist}
Summary:	Collection of high-performance ray tracing kernels developed at Intel
License:	ASL 2.0
URL:		https://embree.github.io
Source0:	https://github.com/%{srcname}/%{srcname}/archive/v%{version}/%{srcname}-%{version}.tar.gz
#Patch0:		rtcore_bvh_builder.patch

BuildRequires:	gcc-c++
BuildRequires:	cmake
BuildRequires:	make
BuildRequires:	ispc
BuildRequires:	freeglut-devel
BuildRequires:	ImageMagick-c++-devel
BuildRequires:	libXmu-devel,libXi-devel
BuildRequires:	tbb-devel
# Use 64bit architectures because of SSE2 and up
ExclusiveArch:	x86_64

%description
A collection of high-performance ray tracing kernels intended to graphics 
application engineers that want to improve the performance of their application.

%package	devel
Summary:	Development files for %{name}
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description	devel
The %{name}-devel package contains libraries and header files for
 applications that use %{name}.

%package	examples
Summary:	Example of application using %{name}
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description	examples
The %{name}-examples package contains sample binaries using %{name}.

%prep
%autosetup -n %{srcname}-%{version}

mkdir %{_target_platform}

%build
pushd %{_target_platform} 
export CXXFLAGS="%{optflags} -Wl,--as-needed"
  %cmake \
	-DEMBREE_IGNORE_CMAKE_CXX_FLAGS=OFF \
	..
popd
%make_build -C %{_target_platform}

%install
%make_install -C %{_target_platform}
# Related binary examples
mkdir -p %{buildroot}%{_libexecdir}/%{name}
mv %{buildroot}%{_bindir}/%{name}/* %{buildroot}%{_libexecdir}/%{name}/

%check
ctest -V %{?_smp_mflags}

%post %ldconfig_scriptlets

%postun %ldconfig_scriptlets


%files
%license LICENSE.txt
%doc README.md CHANGELOG.md readme.pdf LICENSE.txt
%{_libdir}/lib%{srcname}.so.2
%{_libdir}/lib%{srcname}.so.2.*

%files devel
%{_libdir}/lib%{srcname}.so
%{_includedir}/%{name}/
%{_libdir}/cmake/%{srcname}-%{version}/

%files examples
%{_libexecdir}/%{name}/


%changelog
* Wed Jul 24 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.17.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Feb 22 2019 Luya Tshimbalanga <luya@fedoraproject.org> - 2.17.7-1
- Update to 2.17.7

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.17.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Thu Nov 01 2018 Luya Tshimbalanga <luya@fedoraproject.org> - 2.17.6-1
- Update to 2.17.6

* Sun Oct 21 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.17.5-1
- Update to 2.17.5

* Thu Jul 12 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.17.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sun May 27 2018 Luya Tshimbalanga <luya@fedoraproject.org> - 2.17.4-5
- Drop failed patched attempt

* Sun Apr 01 2018 Luya Tshimbalanga <luya@fedoraproject.org> - 2.17.4-3
- Rebuild

* Fri Mar 23 2018 Luya Tshimbalanga  <luya@fedoraproject.org> - 2.17.4-2
- Use macro for ldconfig

* Mon Mar 19 2018 Luya Tshimbalanga  <luya@fedoraproject.org> - 2.17.4-1
- Update to 2.17.4 

* Wed Jan 17 2018 Fedora Release Monitoring  <release-monitoring@fedoraproject.org> - 2.17.2-1
- Update to 2.17.2 (#1512896)

* Wed Oct 25 2017 Luya Tshimbalanga <luya@fedoraproject.org> - 2.17.0-2
- Rebase to more current snapshot for LLVM 5.0 support

* Thu Sep 21 2017 Fedora Release Monitoring  <release-monitoring@fedoraproject.org> - 2.17.0-1
- Update to 2.17.0 (#1494058)

* Tue Aug 15 2017 Fedora Release Monitoring  <release-monitoring@fedoraproject.org> - 2.16.5-1
- Update to 2.16.5 (#1481678)

* Sun Aug 06 2017 Björn Esser <besser82@fedoraproject.org> - 2.16.4-4
- Rebuilt for AutoReq cmake-filesystem

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.16.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.16.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Jun 30 2017 Fedora Release Monitoring  <release-monitoring@fedoraproject.org> - 2.16.4-1
- Update to 2.16.4 (#1466767)

* Thu Jun 15 2017 Fedora Release Monitoring  <release-monitoring@fedoraproject.org> - 2.16.2-1
- Update to 2.16.2 (#1459537)

* Wed May 17 2017 Luya Tshimbalanga <luya@fedoraproject.org> - 2.16.0-1
- New srcname release

* Tue Mar 28 2017 Mamoru TASAKA <mtasaka@fedoraproject.org> - 2.15.0-2
- Honor Fedora compilation flags again (rhbz#1436075)

* Wed Mar 22 2017 Luya Tshimbalanga <luya@fedoraproject.org> - 2.15.0-1
- New srcname release

* Thu Mar 16 2017 Luya Tshimbalanga <luya@fedoraproject.org> - 2.14.0-3
- Rebuild for ispc

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.14.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Feb 09 2017 Luya Tshimbalanga <luya@fedoraproject.org> - 2.14.0-1
- New srcname release
- Drop patch as the fix is included srcname

* Thu Jan 19 2017 Luya Tshimbalanga <luya@fedoraproject.org> - 2.13.0-3
- Patch fixing initialization code of the rayStreamFilters sent by srcname (rhbz#1414611)

* Thu Jan 19 2017 Luya Tshimbalanga <luya@fedoraproject.org> - 2.13.0-2
- Workaround lowering max_ISA to avx on non-Intel CPU (rhbz#1414611)

* Tue Nov 22 2016 Luya Tshimbalanga <luya@fedoraproject.org> - 2.13.0-1
- srcname update

* Tue Oct 18 2016 Luya Tshimbalanga <luya@fedoraproject.org> 2.12.0-1
- srcname update addressing larger memory consumption

* Sat Sep 24 2016 Luya Tshimbalanga <luya@fedoraproject.org> 2.11.0-1
- Latest srcname update

* Thu Sep 22 2016 Jerry James <loganjerry@gmail.com> 2.10.0-8
- Rebuild for tbb 2017

* Thu Aug 25 2016 Luya Tshimbalanga <luya@fedoraproject.org> 2.10.0-7
- Used ExclusiveArch for 64bit Architecture

* Sun Aug 21 2016 Luya Tshimbalanga <luya@fedoraproject.org> 2.10.0-6
- Located flags before cmake
- Used libexecdir for subpackages examples
- Pleased rpmlint
- Added examples subpackages

* Sat Aug 20 2016 Luya Tshimbalanga <luya@fedoraproject.org> 2.10.0-5
- Silenced all warning message in build
- Added %%check line
- Added examples subpackages

* Sat Aug 20 2016 Luya Tshimbalanga <luya@fedoraproject.org> 2.10.0-4
- Added ispc dependency
- Removed ExclusiveArch
- Enabled ispc and tutorials

* Fri Aug 12 2016 Luya Tshimbalanga <luya_tfz@thefinalzone.net> 2.10.0-3
- Use ExclusiveArch tag for 64 bits architectures
- Adjust the lines of descriptions
- Fix bin path
- Add freeglut dependency from srcname

* Sat Aug 6 2016 Luya Tshimbalanga <luya_tfz@thefinalzone.net> 2.10.0-2
- Fixed mixed use space and tabs errors
- Shorten the line of description
- Exclude i686 architecture

* Thu Aug 4 2016 Luya Tshimbalanga <luya_tfz@thefinalzone.net> 2.10.0-1
- Initial build
